@@ -5,9 +5,10 @@
 #'
 #' @param var The variable that should be dichotomized.
 #' @param dichBy Indicates the split criterion where the variable is dichotomized. By default,
-#'          \code{var} is split into two groups at the median (\code{dichBy="median"}). Further
-#'          values for \code{dichBy} are \code{"mean"} (split into groups at the mean of \code{var})),
-#'          and \code{"value"}. In the latter case, you have to specifiy \code{dichVal}.
+#'          \code{var} is split into two groups at the median (\code{dichBy="median"} or
+#'          \code{dichBy="md"}). Further values for \code{dichBy} are \code{"mean"} (or \code{"m"}),
+#'          which splits into groups at the mean of \code{var}; and \code{"value"} (or \code{"v"}).
+#'          In the latter case, you have to specifiy \code{dichVal}.
 #' @param dichVal Indicates a value where \code{var} is dichotomized when \code{dichBy="value"}.
 #'          Note that \code{dichVal} is inclusive, i.e. \code{dichVal=10} will split \code{var}
 #'          into one group with values from lowest to 10 and another group with values greater
@@ -23,6 +24,10 @@
 #'  
 #' @export
 sju.dicho <- function(var, dichBy="median", dichVal=-1) {
+  # check abbreviations
+  if (dichBy=="md") dichBy <- "median"
+  if (dichBy=="m") dichBy <- "mean"
+  if (dichBy=="v") dichBy <- "value"
   # check if factor
   if (is.factor(var)) {
     # try to convert to numeric
@@ -233,11 +238,21 @@ sju.groupVarLabels <- function(var, groupsize=5, rightInterval=FALSE, autoGroupC
 #' @name sju.betaCoef
 #' @description Returns the standardized beta coefficients of a fitted linear model.
 #' 
-#' @seealso \code{\link{sjp.lm}}
+#' @seealso \code{\link{sjp.lm}} \cr
+#'          \code{\link{sjt.lm}}
 #'         
 #' @param fit A fitted linear model.
 #' @return The standardiized beta coefficients of the fitted linear model.
 #' 
+#' @note "Standardized coefficients refer to how many standard deviations a dependent variable will change, 
+#'         per standard deviation increase in the predictor variable. Standardization of the coefficient is 
+#'         usually done to answer the question of which of the independent variables have a greater effect 
+#'         on the dependent variable in a multiple regression analysis, when the variables are measured 
+#'         in different units of measurement (for example, income measured in dollars and family size 
+#'         measured in number of individuals)." (Source: Wikipedia)
+#' 
+#' @references \url{http://en.wikipedia.org/wiki/Standardized_coefficient}
+#' 
 #' @examples
 #' # fit linear model
 #' fit <- lm(airquality$Ozone ~ airquality$Wind + airquality$Temp + airquality$Solar.R)
@@ -254,55 +269,6 @@ sju.betaCoef <- function(fit) {
 }
 
 
-#' @title Retrieve model summary of lm
-#' @name sju.modsum.lm
-#' @description Returns a model summary of a fitted linear model as \link{expression}.
-#'                The summary includes intercept, r2, F-statistics and AIC.
-#'                It is returned as \link{expression} string to be used in plots
-#'                like ggplot.
-#'                
-#' @seealso \code{\link{sjp.lm}} \cr
-#'          \code{\link{sjp.lm1}} \cr
-#'          \code{\link{sjp.lm.ma}}
-#'         
-#' @param fit A fitted linear model.
-#' @return The model summary of the fitted linear model as \link{expression} string.
-#' 
-#' @examples
-#' # fit linear model
-#' fit <- lm(airquality$Ozone ~ airquality$Wind + airquality$Temp + airquality$Solar.R)
-#' # print model summary
-#' sju.modsum.lm(fit)
-#'
-#' @export
-sju.modsum.lm <- function(fit) {
-  # get F-statistics
-  fstat <- summary(fit)$fstatistic
-  # Calculate p-value for F-test
-  pval <- pf(fstat[1], fstat[2], fstat[3],lower.tail = FALSE)
-  # indicate significance level by stars
-  pan <- c("")
-  if (pval<=0.005) {
-    pan <- c("***")
-  }
-  else  if (pval<=0.01) {
-    pan <- c("**")
-  }
-  else  if (pval<=0.05) {
-    pan <- c("*")
-  }
-  # create mathematical term
-  modsum <- as.character(as.expression(
-    substitute(italic(b[0]) == a * "," ~~ R^2 == r2 * "," ~~ "F" == f*panval * "," ~~ "AIC" == aic,
-               list(a=format(coef(fit)[1], digits=3),
-                    r2=format(summary(fit)$r.squared, digits=3),
-                    f=sprintf("%.2f", fstat[1]),
-                    panval=pan,
-                    aic=sprintf("%.2f", AIC(fit))))))
-  return(modsum)
-}
-
-
 #' @title Adjust y range of ggplot-objects
 #' @name sju.adjustPlotRange.y
 #' @description This method adjusts the y-range of a ggplot-object, which is useful when
@@ -315,7 +281,7 @@ sju.modsum.lm <- function(fit) {
 #' @references \url{http://www.r-bloggers.com/setting-axis-limits-on-ggplot-charts/}
 #' 
 #' @param gp A ggplot-object. Usually, this will be returned by most of this
-#'          package's plotting functions via the \code{returnPlot} parameter.
+#'          package's plotting functions.
 #' @param upperMargin Defines the margin of the upper y bound of the plot. This value will
 #'          be multiplied with the total y range. Default is 1.05, which means that the upper
 #'          margin of the plot is about 5 percent of the "visible" plot area (i.e. the y-range
@@ -328,11 +294,11 @@ sju.modsum.lm <- function(fit) {
 #' data(efc)
 #' # show frequencies of relationship-variable and
 #' # retrieve plot object
-#' gp <- sjp.frq(efc$e15relat, returnPlot=TRUE)
+#' gp <- sjp.frq(efc$e15relat, printPlot=FALSE)
 #' # show current plot
-#' plot(gp)
+#' plot(gp$plot)
 #' # show adjusted plot
-#' sju.adjustPlotRange.y(gp)
+#' sju.adjustPlotRange.y(gp$plot)
 #' 
 #' @export
 sju.adjustPlotRange.y <- function(gp, upperMargin=1.05) {
@@ -359,23 +325,34 @@ sju.adjustPlotRange.y <- function(gp, upperMargin=1.05) {
 #' @param labels The label(s) (i.e. character string). You can also pass several strings as vector
 #'          (e.g. \code{labels=c("first long string", "second long string")})
 #' @param wrap The amount of chars per line (i.e. line length)
+#' @param linesep By default, this parameter is \code{NULL} and a regular new line
+#'          string is used. For HTML-needs, for instance, \code{linesep} could be \code{"<br>"}.
 #' @return New label(s) with line breaks inserted at every \code{wrap}'s position.
 #' 
 #' @examples
 #' sju.wordwrap(c("A very long string", "And another even longer string!"), 10)
 #' 
 #' @export
-sju.wordwrap <- function(labels, wrap) {
+sju.wordwrap <- function(labels, wrap, linesep=NULL) {
   # check for valid value
   if (is.null(labels)) {
     return(NULL)
   }
+  # default line separator is \n
+  if (is.null(linesep)) {
+    linesep <- '\\1\n'
+  }
+  else {
+    # however, for html-function we can use "<br>"
+    # as parameter
+    linesep <- sprintf("\\1%s", linesep)
+  }
   # create regex pattern for line break
   pattern <- c(paste('(.{1,', wrap, '})(\\s|$)', sep=""))
   # iterate all labels
   for (n in 1:length(labels)) {
     # insert line breaks
-    labels[n] <- gsub(pattern, '\\1\n', labels[n])
+    labels[n] <- gsub(pattern, linesep, labels[n])
     # -----------------------
     # in case label was short enough, we still have a line break
     # at the end of the label. here we remove any trailing line breaks
@@ -452,7 +429,28 @@ sju.recodeTo <- function(var, lowest=0, highest=-1) {
 }
 
 
-#' @title Plot multicollinearity of linear models
+#' @title Recode variable values.
+#' @name sju.recode
+#' @description Recodes the categories of a variables. Wrapper function that calls
+#'                the \code{\link{recode}} function from the \code{car} package.
+#'
+#' @param ... parameters, see \code{\link{recode}} function from the \code{car} package.
+#' @return A variable with recoded values.
+#' 
+#' @examples
+#' data(efc)
+#' table(efc$e42dep)
+#' table(sju.recode(efc$e42dep, "1:2=1;3:4=2"))
+#'
+#' @importFrom car recode
+#' @export
+sju.recode <- function(...) {
+  # return recoded var
+  return(recode(...))
+}
+
+
+#' @title Plot Variance Inflation Factors of linear models
 #' @name sjp.vif
 #' @description Plots the Variance Inflation Factors (check for multicollinearity) of 
 #'                (generalized) linear models. Values below 5 are good and indicating no
@@ -462,7 +460,7 @@ sju.recodeTo <- function(var, lowest=0, highest=-1) {
 #'
 #' @param fit The fitted (generalized) linear model which should be checked for
 #'          multicollinearity.
-#' @param printnumbers If \code{TRUE} (default), the VIF value are also printed to console.
+#' @return (invisibly) returns the VIF values.
 #' 
 #' @examples
 #' # fit linear model
@@ -472,16 +470,12 @@ sju.recodeTo <- function(var, lowest=0, highest=-1) {
 #' 
 #' @importFrom car vif
 #' @export
-sjp.vif <- function(fit, printnumbers=TRUE) {
+sjp.vif <- function(fit) {
   # check if we have more than 1 term
   if (length(coef(fit))>2) {
     # variance inflation factor
     # claculate VIF
     vifval <- vif(fit)
-    # Wenn VIF-Werte an Konsole ausgegeben werden sollen, diese nun ausdrucken
-    if (printnumbers) {
-      print(vifval)
-    }
     if (is.matrix(vifval)) {
       val <- vifval[,1]
     }
@@ -530,6 +524,7 @@ sjp.vif <- function(fit, printnumbers=TRUE) {
             # Beschriftung der X-Achse (Variablenlabel) in 45-Grad-Winkel setzen
             theme(axis.text.x=element_text(angle=45, vjust=0.5, size=rel(1.2))))
   }
+  invisible(vifval)
 }
 
 
@@ -555,8 +550,310 @@ sjp.vif <- function(fit, printnumbers=TRUE) {
 #' 
 #' @export
 sju.setNA <- function(var, values) {
+  # iterate all values that should be 
+  # replaced by NA's
   for (i in seq_along(values)) {
+    # find associated values in var
+    # and set them to NA
     var[var==values[i]] <- NA
   }
   return(var)
 }
+
+
+#' @title Weight a variable
+#' @name sju.weight2
+#' @description This function weights the variable \code{var} by
+#'                a specific vector of \code{weights}. It's an 
+#'                alternative weight calculation to \code{\link{sju.weight}},
+#'                where \code{\link{sju.weight}} usage is recommended.
+#'                This function sums up all \code{weights} values of the associated
+#'                categories of \code{var}, whereas the \code{\link{sju.weight}} function
+#'                uses a \code{\link{xtabs}} formula to weight cases. Thus, this function
+#'                may return a value with a different length than that from \code{var}.
+#'
+#' @seealso \code{\link{sju.weight}}
+#'
+#' @param var The (unweighted) variable 
+#' @param weights A vector with same length as \code{var}, which
+#'          contains weight factors. Each value of \code{var} has a
+#'          specific assigned weight in \code{weights}.
+#' 
+#' @return The weighted \code{var}.
+#' 
+#' @note The values of the returned vector are in sorted order, whereas the categories
+#'        of the original \code{var} may be spread randomly. Hence, \code{var} can't be
+#'        used, for instance, for further cross tabulation. In case you want to have
+#'        weighted contingency tables or (grouped) box plots etc., use the \code{weightBy}
+#'        parameter of most functions (like in \code{\link{sjt.xtab}} or \code{\link{sjp.grpfrq}}).
+#' 
+#' @examples
+#' v <- sample(1:4, 20, TRUE)
+#' table(v)
+#' w <- abs(rnorm(20))
+#' table(sju.weight2(v,w))
+#' 
+#' @export
+sju.weight2 <- function(var, weights) {
+  items <- unique(var)
+  newvar <- c()
+  for (i in 1:length(items)) {
+    newcount = round(sum(weights[which(var==items[i])]))
+    newvar <- c(newvar, rep(items[i], newcount))
+  }
+  return (newvar)
+}
+
+
+#' @title Weight a variable
+#' @name sju.weight
+#' @description This function weights the variable \code{var} by
+#'                a specific vector of \code{weights}.
+#'
+#' @seealso \code{\link{sju.weight2}}
+#' 
+#' @param var The (unweighted) variable 
+#' @param weights A vector with same length as \code{var}, which
+#'          contains weight factors. Each value of \code{var} has a
+#'          specific assigned weight in \code{weights}.
+#' 
+#' @return The weighted \code{var}.
+#' 
+#' @note The values of the returned vector are in sorted order, whereas the categories
+#'        of the original \code{var} may be spread randomly. Hence, \code{var} can't be
+#'        used, for instance, for further cross tabulation. In case you want to have
+#'        weighted contingency tables or (grouped) box plots etc., use the \code{weightBy}
+#'        parameter of most functions (like in \code{\link{sjt.xtab}} or \code{\link{sjp.grpfrq}}).
+#' 
+#' @examples
+#' v <- sample(1:4, 20, TRUE)
+#' table(v)
+#' w <- abs(rnorm(20))
+#' table(sju.weight(v,w))
+#' 
+#' @export
+sju.weight <- function(var, weights) {
+  # init values
+  weightedvar <- c()
+  wtab <- round(xtabs(weights ~ var, data=data.frame(cbind(weights=weights,var=var))))
+  # iterate all table values
+  for (w in 1:length(wtab)) {
+    # retrieve count of each table cell
+    w_count <- wtab[[w]]
+    # retrieve "cell name" which is identical to the variable value
+    w_value <- as.numeric(names(wtab[w]))
+    # append variable value, repeating it "w_count" times.
+    weightedvar <- c(weightedvar, rep(w_value, w_count))
+  }
+  return(weightedvar)
+}
+
+
+
+#' @title Performs a Mann-Whitney-U-Test
+#' @name sju.mwu
+#' @description This function performs a Mann-Whitney-U-Test (or \code{Wilcoxon rank sum test},
+#'                see \code{\link{wilcox.test}}) for the variable \code{var}, which is
+#'                divided into groups indicated by \code{grp} (so the formula \code{var ~ grp}
+#'                is used). If \code{grp} has more than two categories, a comparison between each 
+#'                two groups is performed.
+#'
+#' @param var A numeric vector / variable, where the Mann-Whitney-U-Test should be applied to.
+#' @param grp The grouping variable indicating the groups that should be used for comparison.
+#' @param alternative a character string specifying the alternative hypothesis, must be one 
+#'          of \code{"two.sided"} (default), \code{"greater"} or \code{"less"}. You can 
+#'          specify just the initial letter.
+#' @return (Invisibly) returns a data frame with p-values for each group-comparison.
+#' 
+#' @note This function calls the \code{\link{wilcox.test}} with formula. If \code{grp}
+#'         has more than two groups, additionally a Kruskal-Wallis-Test (see \code{\link{kruskal.test}})
+#'         is performed.
+#' 
+#' @examples
+#' data(efc)
+#' # Mann-Whitney-U-Tests for elder's age by elder's dependency.
+#' sju.mwu(efc$e17age, efc$e42dep)
+#' 
+#' @export
+sju.mwu <- function(var, grp, alternative="two.sided") {
+  if (min(na.omit(grp))==0) {
+    grp <- grp+1
+  }
+  cnt <- length(unique(na.omit(grp)))
+  cat("\nPerforming Mann-Whitney-U-Test...\n")
+  cat("---------------------------------\n")
+  cat("(showing p-levels between groups (x|y)\n")
+  df <- data.frame()
+  for (i in 1:cnt) {
+    for (j in i:cnt) {
+      if (i!=j) {
+        xsub <- var[which(grp==i | grp==j)]
+        ysub <- grp[which(grp==i | grp==j)]
+        ysub <- ysub[which(!is.na(xsub))]
+        xsub <- as.numeric(na.omit(xsub))
+        ysub <- as.numeric(na.omit(ysub))
+        wt <- wilcox.test(xsub ~ ysub, paired=FALSE, alternative=alternative)
+        cat(sprintf("p(%i|%i)=%.3f\n", i, j, wt$p.value))
+        df <- rbind(df, cbind(grp1=i, grp2=j, p=wt$p.value))
+      }
+    }
+  }
+  # if we have more than 2 groups, also perfom kruskal-wallis-test
+  if (cnt>2) {
+    cat("\nPerforming Kruskal-Wallis-Test...\n")
+    cat("---------------------------------\n")
+    kw <- kruskal.test(var, grp)
+    cat(sprintf("chi-squared=%.3f\n",kw$statistic ))
+    cat(sprintf("df=%i\n",kw$parameter ))
+    cat(sprintf("p=%.3f\n",kw$p.value ))
+  }
+  invisible(df)
+}
+
+
+#' @title Calculates Cronbach's Alpha for a matrix
+#' @name sju.cronbach
+#' @description This function calcates the Cronbach's alpha value for each column
+#'                of a data frame or matrix.
+#'
+#' @param df A data frame or matrix with more than 2 columns.
+#' @return The Cronbach's alpha value for \code{df}.
+#' 
+#' @note For use case, see \code{\link{sjp.pca}} and \code{\link{sjt.pca}}.
+#' 
+#' @export
+sju.cronbach <- function(df) { # df must be matrix or data.frame with more than 2 columns
+  df <- na.omit(df)
+  if (is.null(ncol(df)) || ncol(df)<2) {
+    cat("\nToo less columns in this factor to calculate alpha value!\n")
+    return(0)
+  }
+  return (dim(df)[2]/(dim(df)[2]-1)*(1-sum(apply(df,2,var))/var(rowSums(df))))
+}    
+
+
+#' @title Performs a reliability test on an item scale.
+#' @name sju.reliability
+#' @description This function calcates the corrected item-total correlations for each item of \code{df}
+#'                with the remaining items; furthermore, the Cronbach's alpha for each item, if it was
+#'                deleted from the scale, is calculated.
+#'
+#' @param df A data frame with 
+#' @param scaleItems If \code{TRUE}, the data frame's vectors will be scaled. Recommended,
+#'          when the variables have different measures / scales.
+#' @param digits Amount of digits for Cronbach's Alpha and correlation values in
+#'          returned data frame.
+#' @return A data frame with the corrected item-total correlations and Cronbach's alpha (if item deleted)
+#'           for each item of the scale.
+#' 
+#' @note This function is similar to a basic reliability test in SPSS. The correlations in
+#'         the Item-Total-Statistic are a computed correlation of each item against the sum
+#'         of the remaining items (which are thus treated as one item).
+#' 
+#' @examples
+#' # -------------------------------
+#' # Data from the EUROFAMCARE sample dataset
+#' # -------------------------------
+#' data(efc)
+#' 
+#' # retrieve variable and value labels
+#' varlabs <- sji.getVariableLabels(efc)
+#' 
+#' # recveive first item of COPE-index scale
+#' start <- which(colnames(efc)=="c82cop1")
+#' # recveive last item of COPE-index scale
+#' end <- which(colnames(efc)=="c90cop9")
+#'  
+#' # create data frame with COPE-index scale
+#' df <- as.data.frame(efc[,c(start:end)])
+#' colnames(df) <- varlabs[c(start:end)]
+#' 
+#' \dontrun{
+#' sjt.df(sju.reliability(df), 
+#'        describe=FALSE,
+#'        showCommentRow=TRUE, 
+#'        commentString=sprintf("Cronbach's &alpha;=%.2f", sju.cronbach(df)))}
+#' 
+#' # ---------------------------------------
+#' # Compute PCA on Cope-Index, and perform a
+#' # reliability check on each extracted factor.
+#' # ---------------------------------------
+#' \dontrun{
+#' factors <- sjt.pca(df)$factor.index
+#' findex <- sort(unique(factors))
+#' for (i in 1:length(findex)) {
+#'  rel.df <- subset(df, select=which(factors==findex[i]))
+#'  if (ncol(rel.df)>=3) {
+#'    sjt.df(sju.reliability(rel.df),
+#'           describe=FALSE,
+#'           showCommentRow=TRUE,
+#'           useViewer=FALSE,
+#'           title="Item-Total-Statistic",
+#'           commentString=sprintf("Scale's overall Cronbach's &alpha;=%.2f", 
+#'                                 sju.cronbach(rel.df)))
+#'    }
+#'  }}
+#'  
+#' @export
+sju.reliability <- function(df, scaleItems=FALSE, digits=3) {
+  # -----------------------------------
+  # check for minimum amount of columns
+  # can't be less than 3, because the reliability
+  # test checks for Cronbach's alpha if a specific
+  # item is deleted. If data frame has only two columns
+  # and one is deleted, Cronbach's alpha cannot be calculated.
+  # -----------------------------------
+  if (ncol(df)<3) {
+    stop("Data frame needs at least three columns!", call.=FALSE)
+  }
+  # -----------------------------------
+  # remove missings, so correlation works
+  # -----------------------------------
+  df <- na.omit(df)
+  # -----------------------------------
+  # remember item (column) names for return value
+  # return value gets column names of initial data frame
+  # -----------------------------------
+  df.names <- colnames(df)
+  # -----------------------------------
+  # Check whether items should be scaled. Needed,
+  # when items have different measures / scales
+  # -----------------------------------
+  if (scaleItems) {
+    df <- data.frame(scale(df, center=TRUE, scale=TRUE))
+  }
+  # -----------------------------------
+  # init vars
+  # -----------------------------------
+  totalCorr <- c()
+  cronbachDeleted <- c()
+  # -----------------------------------
+  # iterate all items
+  # -----------------------------------
+  for (i in 1:ncol(df)) {
+    # -----------------------------------
+    # create subset with all items except current one
+    # (current item "deleted")
+    # -----------------------------------
+    sub.df <- subset(df, select=c(-i))
+    # -----------------------------------
+    # calculate cronbach-if-deleted
+    # -----------------------------------
+    cronbachDeleted <- c(cronbachDeleted, sju.cronbach(sub.df))
+    # -----------------------------------
+    # calculate corrected total-item correlation
+    # -----------------------------------
+    totalCorr <- c(totalCorr, cor(df[,i], apply(sub.df, 1, sum), use="pairwise.complete.obs"))
+  }
+  # -----------------------------------
+  # create return value
+  # -----------------------------------
+  ret.df <- data.frame(cbind(round(cronbachDeleted,digits), round(totalCorr,digits)))
+  # -----------------------------------
+  # set names of data frame
+  # -----------------------------------
+  colnames(ret.df) <- c("Cronbach's &alpha; if item deleted", "Corrected item-total correlation")
+  rownames(ret.df) <- df.names
+  # -----------------------------------
+  return(ret.df)
+}
