@@ -1,9 +1,15 @@
-#' @title Save frequencies as HTML table
+#' @title Show frequencies as HTML table
 #' @name sjt.frq
 #' 
-#' @description Save (multiple) frequency tables as HTML file.
+#' @description Shows (multiple) frequency tables as HTML file, or saves them as file.
 #' 
-#' @seealso \link{sjp.frq}
+#' @references \itemize{
+#'              \item \url{http://strengejacke.wordpress.com/sjplot-r-package/}
+#'              \item \url{http://strengejacke.wordpress.com/2014/02/20/no-need-for-spss-beautiful-output-in-r-rstats/}
+#'              }
+#' 
+#' @seealso \code{\link{sjp.frq}} \cr
+#'          \code{\link{sjt.xtab}}
 #' 
 #' @param data The variables which frequencies should be printed as table. Either use a single variable
 #'          (vector) or a data frame where each column represents a variable (see examples.
@@ -21,10 +27,10 @@
 #'          from \code{data}. Note that if multiple variables are supplied (as data frame), the 
 #'          value labels must be supplied as nested \code{list} object (see examples).
 #' @param autoGroupAt A value indicating at which length of unique values a variable from \code{data}
-#'          is automatically grouped into smaller units (see \link{sju.groupVar}). Variables with large 
+#'          is automatically grouped into smaller units (see \code{\link{sju.groupVar}}). Variables with large 
 #'          numbers of unique values may be too time consuming when a HTML table is created and R would
 #'          not respond any longer. Hence it's recommended to group such variables. Default value is 50,
-#'          i.e. variables with 50 and more unique values will be grouped using \link{sju.groupVar} with
+#'          i.e. variables with 50 and more unique values will be grouped using \code{\link{sju.groupVar}} with
 #'          \code{groupsize="auto"} parameter. By default, the maximum group count is 30. However, if
 #'          \code{autoGroupAt} is less than 30, \code{autoGroupAt} groups are built. Default value is \code{NULL},
 #'          i.e. auto-grouping is turned off.
@@ -46,10 +52,46 @@
 #' @param skipZeroRows If \code{TRUE}, rows with only zero-values are not printed. Default is \code{FALSE}.
 #' @param showSummary If \code{TRUE} (default), a summary row with total and valid N as well as mean and
 #'          standard deviation is shown.
+#' @param showSkew If \code{TRUE}, the variable's skewness is added to the summary.
+#'          The skewness is retrieved from the \code{\link{describe}} function of the \code{\link{psych}}
+#'          package.
+#' @param showKurtosis If \code{TRUE}, the variable's kurtosis is added to the summary.
+#'          The kurtosis is retrieved from the \code{\link{describe}} function of the \code{\link{psych}}
+#'          package.
+#' @param skewString A character string, which is used as header for the skew column (see \code{showSkew})).
+#'          Default is lower case Greek gamma.
+#' @param kurtosisString A character string, which is used as header for the kurtosis column (see \code{showKurtosis})).
+#'          Default is lower case Greek omega.
 #' @param encoding The charset encoding used for variable and value labels. Default is \code{"UTF-8"}. Change
 #'          encoding if specific chars are not properly displayed (e.g.) German umlauts).
-#' @return Invisibly returns a \link{structure} with the web page style sheet (\code{page.style}) and each
-#'          frequency table as web page content (\code{page.content.list}) for further use.
+#' @param CSS A \code{\link{list}} with user-defined style-sheet-definitions, according to the official CSS syntax (see
+#'          \url{http://www.w3.org/Style/CSS/}). See return value \code{page.style} for details
+#'          of all style-sheet-classnames that are used in this function. Parameters for this list need:
+#'          \enumerate{
+#'            \item the class-names with \code{"css."}-prefix as parameter name and
+#'            \item each style-definition must end with a semicolon
+#'          } 
+#'          Examples:
+#'          \itemize{
+#'            \item \code{css.table='border:2px solid red;'} for a solid 2-pixel table border in red.
+#'            \item \code{css.summary='font-weight:bold;'} for a bold fontweight in the summary row.
+#'            \item \code{css.lasttablerow='border-bottom: 1px dotted blue;'} for a blue dotted border of the last table row.
+#'          }
+#'          See further examples below.
+#' @param useViewer If \code{TRUE}, the function tries to show the HTML table in the IDE's viewer pane. If
+#'          \code{FALSE} or no viewer available, the HTML table is opened in a web browser.
+#' @param no.output If \code{TRUE}, the html-output is neither opened in a browser nor shown in
+#'          the viewer pane and not even saved to file. This option is useful when the html output
+#'          should be used in \code{knitr} documents. The html output can be accessed via the return
+#'          value.
+#' @return Invisibly returns a \code{\link{structure}} with
+#'          \itemize{
+#'            \item the web page style sheet (\code{page.style}),
+#'            \item each frequency table as web page content (\code{page.content.list}),
+#'            \item the complete html-output (\code{output.complete}) and
+#'            \item the html-table with inline-css for use with knitr (\code{knitr})
+#'            }
+#'            for further use.
 #'          
 #' @note The HTML tables can either be saved as file and manually opened (specify parameter \code{file}) or
 #'         they can be saved as temporary files and will be displayed in the RStudio Viewer pane (if working with RStudio)
@@ -69,10 +111,9 @@
 #' \dontrun{
 #' sjt.frq(efc$e42dep)}
 #' 
-#' # plot and save frequency table of "e42dep" with labels
+#' # plot and show frequency table of "e42dep" with labels
 #' \dontrun{
 #' sjt.frq(efc$e42dep,
-#'         file="dependency_labels.html",
 #'         variableLabels=variables['e42dep'],
 #'         valueLabels=values[['e42dep']])}
 #' 
@@ -84,15 +125,26 @@
 #'         valueLabels=list(values[['e42dep']], values[['e16sex']], values[['c172code']]))}
 #' 
 #' # plot larger scale including zero-counts
-#' # and save to file, indicating median and quartiles
+#' # indicating median and quartiles
 #' \dontrun{
 #' sjt.frq(efc$neg_c_7,
-#'         file="negativeimpact.html",
 #'         variableLabels=variables['neg_c_7'],
 #'         valueLabels=values[['neg_c_7']],
 #'         highlightMedian=TRUE,
 #'         highlightQuartiles=TRUE)}
 #' 
+#' # ---------------------------------------------------------------- 
+#' # User defined style sheet
+#' # ---------------------------------------------------------------- 
+#' \dontrun{
+#' sjt.frq(efc$e42dep,
+#'         variableLabels=variables['e42dep'],
+#'         valueLabels=values[['e42dep']],
+#'         CSS=list(css.table="border: 2px solid;",
+#'                  css.tdata="border: 1px solid;",
+#'                  css.firsttablecol="color:#003399; font-weight:bold;"))}
+#' 
+#' @importFrom psych describe
 #' @export
 sjt.frq <- function (data,
                      file=NULL,
@@ -111,12 +163,81 @@ sjt.frq <- function (data,
                      highlightQuartiles=FALSE,
                      skipZeroRows=FALSE,
                      showSummary=TRUE,
-                     encoding="UTF-8") {
+                     showSkew=FALSE,
+                     showKurtosis=FALSE,
+                     skewString="&gamma;",
+                     kurtosisString="&omega;",
+                     encoding="UTF-8",
+                     CSS=NULL,
+                     useViewer=TRUE,
+                     no.output=FALSE) {
   # -------------------------------------
   # table init
   # -------------------------------------
   toWrite <- sprintf("<html>\n<head>\n<meta http-equiv=\"Content-type\" content=\"text/html;charset=%s\">\n", encoding)
-  page.style <- "<style>\n.arc { background-color:#eaeaea }\n.qrow { border-bottom: 1px solid #cc3333 }\n.mdrow { font-weight:bolder; font-style:italic; color:#993333 }\n.abstand { margin-bottom: 2em }\ntable { border-collapse:collapse; border:none }\nth { border-top: double; text-align:center; font-style:italic; font-weight:normal }\ntable td { padding:0.2cm }\ntd.summary { text-align:right; font-style:italic; font-size:0.9em; padding-top:0.1cm; padding-bottom:0.1cm }\n.lasttablerow { border-top:1px solid; border-bottom: double }\n.firsttablerow { border-bottom:1px solid }\n.leftalign { text-align:left }\n.centeralign { text-align:center }\ncaption { font-weight: bold; text-align:left  }\n</style>"
+  # -------------------------------------
+  # init style sheet and tags used for css-definitions
+  # we can use these variables for string-replacement
+  # later for return value
+  # -------------------------------------
+  tag.table <- "table"
+  tag.thead <- "thead"
+  tag.tdata <- "tdata"
+  tag.caption <- "caption"
+  tag.summary <- "summary"
+  tag.arc <- "arc"
+  tag.qrow <- "qrow"
+  tag.mdrow <- "mdrow"
+  tag.abstand <- "abstand"
+  tag.lasttablerow <- "lasttablerow"
+  tag.firsttablerow <- "firsttablerow"
+  tag.leftalign <- "leftalign"
+  tag.centeralign <- "centeralign"
+  tag.firsttablecol <- "firsttablecol"
+  css.table <- "border-collapse:collapse; border:none;"
+  css.thead <- "border-top:double; text-align:center; font-style:italic; font-weight:normal; padding-left:0.2cm; padding-right:0.2cm;"
+  css.tdata <- "padding:0.2cm;"
+  css.caption <- "font-weight: bold; text-align:left;"
+  css.summary <- "text-align:right; font-style:italic; font-size:0.9em; padding-top:0.1cm; padding-bottom:0.1cm;"
+  css.arc <- "background-color:#eaeaea;"
+  css.qrow <- "border-bottom: 1px solid #cc3333;"
+  css.mdrow <- "font-weight:bolder; font-style:italic; color:#993333;"
+  css.abstand <- "margin-bottom: 2em;"
+  css.lasttablerow <- "border-top:1px solid; border-bottom:double;"
+  css.firsttablerow <- "border-bottom:1px solid;"
+  css.leftalign <- "text-align:left;"
+  css.centeralign <- "text-align:center;"
+  css.firsttablecol <- ""
+  # ------------------------
+  # check user defined style sheets
+  # ------------------------
+  if (!is.null(CSS)) {
+    if (!is.null(CSS[['css.table']])) css.table <- CSS[['css.table']]
+    if (!is.null(CSS[['css.thead']])) css.thead <- CSS[['css.thead']]
+    if (!is.null(CSS[['css.tdata']])) css.tdata <- CSS[['css.tdata']]
+    if (!is.null(CSS[['css.caption']])) css.caption <- CSS[['css.caption']]
+    if (!is.null(CSS[['css.summary']])) css.summary <- CSS[['css.summary']]
+    if (!is.null(CSS[['css.arc']])) css.arc <- CSS[['css.arc']]
+    if (!is.null(CSS[['css.qrow']])) css.qrow <- CSS[['css.qrow']]
+    if (!is.null(CSS[['css.mdrow']])) css.mdrow <- CSS[['css.mdrow']]
+    if (!is.null(CSS[['css.abstand']])) css.abstand <- CSS[['css.abstand']]
+    if (!is.null(CSS[['css.lasttablerow']])) css.lasttablerow <- CSS[['css.lasttablerow']]
+    if (!is.null(CSS[['css.firsttablerow']])) css.firsttablerow <- CSS[['css.firsttablerow']]
+    if (!is.null(CSS[['css.leftalign']])) css.leftalign <- CSS[['css.leftalign']]
+    if (!is.null(CSS[['css.centeralign']])) css.centeralign <- CSS[['css.centeralign']]
+    if (!is.null(CSS[['css.firsttablecol']])) css.firsttablecol <- CSS[['css.firsttablecol']]
+  }
+  # -------------------------------------
+  # set style sheet
+  # -------------------------------------
+  page.style <- sprintf("<style>\n%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n%s { %s }\n.%s { %s }</style>",
+                        tag.table, css.table, tag.thead, css.thead, tag.tdata, css.tdata,
+                        tag.summary, css.summary, tag.arc, css.arc, tag.qrow, css.qrow,
+                        tag.mdrow, css.mdrow, tag.abstand, css.abstand, tag.lasttablerow, css.lasttablerow,
+                        tag.firsttablerow, css.firsttablerow, tag.leftalign, css.leftalign,
+                        tag.centeralign, css.centeralign, tag.caption, css.caption,
+                        tag.firsttablecol, css.firsttablecol)
+  # start writing content
   toWrite <- paste(toWrite, page.style)
   toWrite <- paste(toWrite, "\n</head>\n<body>\n")
   # -------------------------------------
@@ -162,7 +283,7 @@ sjt.frq <- function (data,
   # header row of table
   # -------------------------------------
   page.content.list <- list()
-  headerRow <- sprintf("   <tr class=\"firsttablerow\">\n     <th>%s</th>\n     <th>%s</th>\n     <th>%s</th>\n     <th>%s</th>\n     <th>%s</th>\n   </tr>\n\n", stringValue, stringCount, stringPerc, stringValidPerc, stringCumPerc)
+  headerRow <- sprintf("   <tr>\n     <th class=\"thead firsttablerow firsttablecol\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n   </tr>\n\n", stringValue, stringCount, stringPerc, stringValidPerc, stringCumPerc)
   # -------------------------------------
   # start iterating all variables
   # -------------------------------------
@@ -249,7 +370,7 @@ sjt.frq <- function (data,
     # -------------------------------------
     # header row with column labels
     # -------------------------------------
-    page.content <- paste(page.content, headerRow)
+    page.content <- paste0(page.content, headerRow)
     # -------------------------------------
     # data rows with value labels
     # -------------------------------------
@@ -304,34 +425,28 @@ sjt.frq <- function (data,
         # -------------------------------------
         # init default values
         rowstring <- ""
-        rowcss <- "<tr>"
         # init default value for alternating colors
         if (alternateRowColors) rowstring <- ifelse(j %% 2 ==0, " arc", "")
+        rowcss <- rowstring
         # check whether we have median row and whether it should be highlighted
         if (highlightMedian && ((j+minval)==(var.median+1))) {
-          rowcss <- sprintf("<tr class=\"mdrow%s\">", rowstring)
+          rowcss <- sprintf(" mdrow%s", rowstring)
         }
+        # check whether we have lower quartile and whether it should be highlighted
         else {
-          # check whether we have lower quartile and whether it should be highlighted
           if (highlightQuartiles) {
             if(((j+minval)==(var.lowerq+1)) || ((j+minval)==(var.upperq+1))) {
-              rowcss <- sprintf("<tr class=\"qrow%s\">", rowstring)
+              rowcss <- sprintf(" qrow%s", rowstring)
             }
-            else {
-              if (alternateRowColors) rowcss <- ifelse(j %% 2 ==0, "<tr class=\"arc\">", "<tr>")
-            }
-          } 
-          else {
-            if (alternateRowColors) rowcss <- ifelse(j %% 2 ==0, "<tr class=\"arc\">", "<tr>")
           }
         }
         # value label
-        page.content <- paste(page.content, sprintf("  %s\n     <td class=\"leftalign\">%s</td>\n", rowcss, vallab[j]))
+        page.content <- paste(page.content, sprintf("  <tr>\n     <td class=\"tdata leftalign firsttablecol%s\">%s</td>\n", rowcss, vallab[j]))
         # cell values, first value is integer
-        page.content <- paste(page.content, sprintf("    <td class=\"centeralign\">%i</td>\n", as.integer(c(datarow[1])[[1]])))
+        page.content <- paste(page.content, sprintf("    <td class=\"tdata centeralign%s\">%i</td>\n", rowcss, as.integer(c(datarow[1])[[1]])))
         for (i in 2:4) {
           # following values are float
-          page.content <- paste(page.content, sprintf("    <td class=\"centeralign\">%.2f</td>\n", c(datarow[i])[[1]]))
+          page.content <- paste(page.content, sprintf("    <td class=\"tdata centeralign%s\">%.2f</td>\n", rowcss, c(datarow[i])[[1]]))
         }
         # close row-tag
         page.content <- paste(page.content, "  </tr>\n", "\n")
@@ -346,11 +461,11 @@ sjt.frq <- function (data,
     # write table data row
     # -------------------------------------
     # value label
-    page.content <- paste(page.content, sprintf("  <tr class=\"lasttablerow\">\n     <td class=\"leftalign\">%s</td>\n", stringMissingValue))
+    page.content <- paste(page.content, sprintf("  <tr>\n     <td class=\"tdata leftalign lasttablerow firsttablecol\">%s</td>\n", stringMissingValue))
     # cell values, first value is integer
-    page.content <- paste(page.content, sprintf("    <td class=\"centeralign\">%i</td>\n", as.integer(c(datarow[1])[[1]])))
+    page.content <- paste(page.content, sprintf("    <td class=\"tdata centeralign lasttablerow\">%i</td>\n", as.integer(c(datarow[1])[[1]])))
     # 2nd value is float. we don't need 3rd and 4th value as they are always 0 and 100
-    page.content <- paste(page.content, sprintf("    <td class=\"centeralign\">%.2f</td>\n     <td></td>\n     <td></td>\n", c(datarow[2])[[1]]))
+    page.content <- paste(page.content, sprintf("    <td class=\"tdata centeralign lasttablerow\">%.2f</td>\n     <td class=\"tdata lasttablerow\"></td>\n     <td class=\"tdata lasttablerow\"></td>\n", c(datarow[2])[[1]]))
     # -------------------------------------
     # add info for mean, standard deviation
     # -------------------------------------
@@ -363,7 +478,13 @@ sjt.frq <- function (data,
       else {
         mw <- weighted.mean(orivar, weightBy, na.rm=TRUE)
       }
-      page.content <- paste(page.content, sprintf("  </tr>\n\n  <tr>\n    <td class=\"summary\" colspan=\"5\">total N=%i &middot; valid N=%i &middot; x&#772;=%.2f &middot; &sigma;=%.2f</td>\n", vartot, varvalid, mw, sd(orivar, na.rm=TRUE)))
+      descr <- ""
+      if (showSkew || showKurtosis) {
+        pstat <- describe(data.frame(orivar))
+        if (showSkew) descr <- sprintf(" &middot; %s=%.2f", skewString, pstat$skew)
+        if (showKurtosis) descr <- sprintf("%s &middot; %s=%.2f", descr, kurtosisString, pstat$kurtosis)
+      }
+      page.content <- paste(page.content, sprintf("  </tr>\n  <tr>\n    <td class=\"tdata summary\" colspan=\"5\">total N=%i &middot; valid N=%i &middot; x&#772;=%.2f &middot; &sigma;=%.2f%s</td>\n", vartot, varvalid, mw, sd(orivar, na.rm=TRUE), descr))
     }
     # -------------------------------------
     # finish table
@@ -385,30 +506,71 @@ sjt.frq <- function (data,
   # -------------------------------------
   # finish html page
   # -------------------------------------
-  toWrite = paste(toWrite, "</body></html>", "\n")
+  toWrite <- paste0(toWrite, "</body></html>")
   # -------------------------------------
-  # check if we have filename specified
+  # replace class attributes with inline style,
+  # useful for knitr
   # -------------------------------------
-  if (!is.null(file)) {
-    # write file
-    write(toWrite, file=file)
-  }
-  else {
-    # else create and browse temporary file
-    htmlFile <- tempfile(fileext=".html")
-    write(toWrite, file=htmlFile)
-    # check whether we have RStudio Viewer
-    viewer <- getOption("viewer")
-    if (!is.null(viewer)) {
-      viewer(htmlFile)
+  # copy page content
+  # -------------------------------------
+  knitr <- page.content
+  # -------------------------------------
+  # set style attributes for main table tags
+  # -------------------------------------
+  knitr <- gsub("class=", "style=", knitr)
+  knitr <- gsub("<table", sprintf("<table style=\"%s\"", css.table), knitr)
+  knitr <- gsub("<caption", sprintf("<caption style=\"%s\"", css.caption), knitr)
+  # -------------------------------------
+  # replace class-attributes with inline-style-definitions
+  # -------------------------------------
+  knitr <- gsub(tag.tdata, css.tdata, knitr)
+  knitr <- gsub(tag.thead, css.thead, knitr)
+  knitr <- gsub(tag.firsttablerow, css.firsttablerow, knitr)
+  knitr <- gsub(tag.firsttablecol, css.firsttablecol, knitr)
+  knitr <- gsub(tag.leftalign, css.leftalign, knitr)  
+  knitr <- gsub(tag.centeralign, css.centeralign, knitr)  
+  knitr <- gsub(tag.lasttablerow, css.lasttablerow, knitr)  
+  knitr <- gsub(tag.summary, css.summary, knitr)  
+  knitr <- gsub(tag.arc, css.arc, knitr)  
+  knitr <- gsub(tag.qrow, css.qrow, knitr)  
+  knitr <- gsub(tag.mdrow, css.mdrow, knitr)  
+  knitr <- gsub(tag.abstand, css.abstand, knitr)  
+  # -------------------------------------
+  # check if html-content should be outputted
+  # -------------------------------------
+  if (!no.output) {
+    # -------------------------------------
+    # check if we have filename specified
+    # -------------------------------------
+    if (!is.null(file)) {
+      # write file
+      write(knitr, file=file)
     }
+    # -------------------------------------
+    # else open in viewer pane
+    # -------------------------------------
     else {
-      utils::browseURL(htmlFile)    
+      # else create and browse temporary file
+      htmlFile <- tempfile(fileext=".html")
+      write(toWrite, file=htmlFile)
+      # check whether we have RStudio Viewer
+      viewer <- getOption("viewer")
+      if (useViewer && !is.null(viewer)) {
+        viewer(htmlFile)
+      }
+      else {
+        utils::browseURL(htmlFile)    
+      }
+      # delete temp file
+      # unlink(htmlFile)
     }
-    # delete temp file
-    # unlink(htmlFile)
   }
+  # -------------------------------------
+  # return results
+  # -------------------------------------
   invisible (structure(class = "sjtfrq",
                        list(page.style = page.style,
-                            page.content.list = page.content.list)))
+                            page.content.list = page.content.list,
+                            output.complete = toWrite,
+                            knitr = knitr)))
 }
